==> haskell-fgl-arbitrary-0.2.0.6-231.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-fgl-arbitrary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fgl-arbitrary
version:              0.2.0.6
visibility:           public
id:                   fgl-arbitrary-0.2.0.6-EfpJok1XC3gfMgrpaloWc
key:                  fgl-arbitrary-0.2.0.6-EfpJok1XC3gfMgrpaloWc
license:              BSD-3-Clause
copyright:            Ivan Lazar Miljenovic
maintainer:           Ivan.Miljenovic@gmail.com
author:               Ivan Lazar Miljenovic
synopsis:             QuickCheck support for fgl
description:
    Provides Arbitrary instances for fgl graphs (to avoid adding a
    QuickCheck dependency for fgl whilst still making the instances
    available to others).

    Also available are non-fgl-specific functions for generating
    graph-like data structures.

category:             Testing, Graphs
abi:                  37884ebf9a1e55f7c6f6de29b12b8f43
exposed:              True
exposed-modules:      Data.Graph.Inductive.Arbitrary
import-dirs:          /usr/lib/ghc-9.6.6/site-local/fgl-arbitrary-0.2.0.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/fgl-arbitrary-0.2.0.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/fgl-arbitrary-0.2.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fgl-arbitrary
hs-libraries:         HSfgl-arbitrary-0.2.0.6-EfpJok1XC3gfMgrpaloWc
depends:
    QuickCheck-2.15.0.1-DMgRmI5QzBCFdvvi5liF0L base-4.18.2.1
    fgl-5.8.3.0-B0TevPI7AiYLxGtQdBg8DH

haddock-interfaces:
    /usr/share/doc/haskell-fgl-arbitrary/html/fgl-arbitrary.haddock

haddock-html:         /usr/share/doc/haskell-fgl-arbitrary/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fgl-arbitrary-0.2.0.6-232-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-fgl-arbitrary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fgl-arbitrary
version:              0.2.0.6
visibility:           public
id:                   fgl-arbitrary-0.2.0.6-3k89BJLPLe2G59AsBYNSV
key:                  fgl-arbitrary-0.2.0.6-3k89BJLPLe2G59AsBYNSV
license:              BSD-3-Clause
copyright:            Ivan Lazar Miljenovic
maintainer:           Ivan.Miljenovic@gmail.com
author:               Ivan Lazar Miljenovic
synopsis:             QuickCheck support for fgl
description:
    Provides Arbitrary instances for fgl graphs (to avoid adding a
    QuickCheck dependency for fgl whilst still making the instances
    available to others).

    Also available are non-fgl-specific functions for generating
    graph-like data structures.

category:             Testing, Graphs
abi:                  484e6337362afaa36b3523970d9ac5e6
exposed:              True
exposed-modules:      Data.Graph.Inductive.Arbitrary
import-dirs:          /usr/lib/ghc-9.6.6/site-local/fgl-arbitrary-0.2.0.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/fgl-arbitrary-0.2.0.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/fgl-arbitrary-0.2.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fgl-arbitrary
hs-libraries:         HSfgl-arbitrary-0.2.0.6-3k89BJLPLe2G59AsBYNSV
depends:
    QuickCheck-2.15.0.1-1xFq7rzYyJMIIsLto0YgsS base-4.18.2.1
    fgl-5.8.3.0-GZ4l8hdJ4noD1bffNtTEn2

haddock-interfaces:
    /usr/share/doc/haskell-fgl-arbitrary/html/fgl-arbitrary.haddock

haddock-html:         /usr/share/doc/haskell-fgl-arbitrary/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
